package java.awt.image;

import java.util.Hashtable;

public class ReplicateScaleFilter extends ImageFilter
{
    protected int srcWidth;
    protected int srcHeight;
    protected int destWidth;
    protected int destHeight;
    protected int[] srcrows;
    protected int[] srccols;
    protected Object outpixbuf;
    
    public ReplicateScaleFilter(int n, int n2) {
        if (n == 0 || n2 == 0) {
            throw new IllegalArgumentException("Width (" + n + ") and height (" + n2 + ") must be non-zero");
        }
        this.destWidth = n;
        this.destHeight = n2;
        return;
    }
    
    @Override
    public void setProperties(Hashtable<?, ?> hashtable) {
        Hashtable<String, String> properties = (Hashtable)hashtable.clone();
        String s = "rescale";
        String s2 = this.destWidth + "x" + this.destHeight;
        Object value = properties.get(s);
        if (value != null && value instanceof String) {
            s2 = (String)value + ", " + s2;
        }
        properties.put(s, s2);
        super.setProperties(properties);
    }
    
    @Override
    public void setDimensions(int srcWidth, int srcHeight) {
        this.srcWidth = srcWidth;
        this.srcHeight = srcHeight;
        if (this.destWidth < 0) {
            if (this.destHeight < 0) {
                this.destWidth = this.srcWidth;
                this.destHeight = this.srcHeight;
            }
            else {
                this.destWidth = this.srcWidth * this.destHeight / this.srcHeight;
            }
        }
        else if (this.destHeight < 0) {
            this.destHeight = this.srcHeight * this.destWidth / this.srcWidth;
        }
        this.consumer.setDimensions(this.destWidth, this.destHeight);
    }
    
    private void calculateMaps() {
        this.srcrows = new int[this.destHeight + 1];
        for (int i = 0; i <= this.destHeight; ++i) {
            this.srcrows[i] = (2 * i * this.srcHeight + this.srcHeight) / (2 * this.destHeight);
        }
        this.srccols = new int[this.destWidth + 1];
        for (int j = 0; j <= this.destWidth; ++j) {
            this.srccols[j] = (2 * j * this.srcWidth + this.srcWidth) / (2 * this.destWidth);
        }
    }
    
    @Override
    public void setPixels(int n, int n2, int n3, int n4, ColorModel colorModel, byte[] array, int n5, int n6) {
        if (this.srcrows == null || this.srccols == null) {
            this.calculateMaps();
        }
        int n7 = (2 * n * this.destWidth + this.srcWidth - 1) / (2 * this.srcWidth);
        int n8 = (2 * n2 * this.destHeight + this.srcHeight - 1) / (2 * this.srcHeight);
        byte[] outpixbuf;
        if (this.outpixbuf != null && this.outpixbuf instanceof byte[]) {
            outpixbuf = (byte[])(byte[])this.outpixbuf;
        }
        else {
            outpixbuf = new byte[this.destWidth];
            this.outpixbuf = outpixbuf;
        }
        int n9;
        for (; (n9 = this.srcrows[n8]) < n2 + n4; ++n8) {
            int n10 = n5 + n6 * (n9 - n2);
            int n11;
            for (; (n11 = this.srccols[n7]) < n + n3; ++n7) {
                outpixbuf[n7] = array[n10 + n11 - n];
            }
            if (n7 > n7) {
                this.consumer.setPixels(n7, n8, n7 - n7, 1, colorModel, outpixbuf, n7, this.destWidth);
            }
        }
    }
    
    @Override
    public void setPixels(int n, int n2, int n3, int n4, ColorModel colorModel, int[] array, int n5, int n6) {
        if (this.srcrows == null || this.srccols == null) {
            this.calculateMaps();
        }
        int n7 = (2 * n * this.destWidth + this.srcWidth - 1) / (2 * this.srcWidth);
        int n8 = (2 * n2 * this.destHeight + this.srcHeight - 1) / (2 * this.srcHeight);
        int[] outpixbuf;
        if (this.outpixbuf != null && this.outpixbuf instanceof int[]) {
            outpixbuf = (int[])(int[])this.outpixbuf;
        }
        else {
            outpixbuf = new int[this.destWidth];
            this.outpixbuf = outpixbuf;
        }
        int n9;
        for (; (n9 = this.srcrows[n8]) < n2 + n4; ++n8) {
            int n10 = n5 + n6 * (n9 - n2);
            int n11;
            for (; (n11 = this.srccols[n7]) < n + n3; ++n7) {
                outpixbuf[n7] = array[n10 + n11 - n];
            }
            if (n7 > n7) {
                this.consumer.setPixels(n7, n8, n7 - n7, 1, colorModel, outpixbuf, n7, this.destWidth);
            }
        }
    }
}
